@@ -11,10 +11,15 @@
 #ifndef ProjP_H
 #define ProjP_H
 
-#include <proj.h>
 
 #include "magics.h"
 
+#if !defined PROJ_H
+typedef struct PJconsts PJ;
+typedef struct projCtx_t PJ_CONTEXT;
+#endif
+
+
 namespace magics {
 
 class ProjP {
@@ -26,7 +31,7 @@ public:
 
     bool valid() const { return converter_; }
 
-    static string error(int error) { return proj_errno_string(error); }
+    static string error(int error);
 
     virtual int convert(double&, double&) const;
     virtual int revert(double&, double&) const;
@@ -38,6 +43,7 @@ protected:
     string from_;
     string to_;
     PJ* converter_;
+    static PJ_CONTEXT* context_;
 
 private:
     //! Copy constructor - No copy allowed
